@@ -1,16 +1,15 @@
 #ifndef SDOPENCV_HEADERS_H
 #define SDOPENCV_HEADERS_H
 
-#include "cxtypes.h"
+#define __OPENCV_MATRIX_OPERATIONS_H__ // to turn off cxmat.hpp and turn on sdcxmat.hpp -- there's a bug
 #include "cxcore.h"
-#include "cxoperations.hpp"
-#include "cxmat.hpp"
-#include "cxcore.hpp"
+#undef __OPENCV_MATRIX_OPERATIONS_H__
+#include "sdcxmat.hpp"
 
-#include "cvtypes.h"
+#define __OPENCV_CV_HPP__ // to turn off cv.hpp and turn on sdcv.hpp -- there's a bug
 #include "cv.h"
-#include "cvcompat.h"
-#include "cv.hpp"
+#undef __OPENCV_CV_HPP__
+#include "sdcv.hpp"
 
 #include "highgui.h"
 #include "highgui.hpp"
@@ -29,7 +28,7 @@ struct CvGenericHash {};
 struct CvFileStorage {};
 
 struct _CvContourScanner {};
-struct CvHidHaarClassifierCascade {};
+// struct CvHidHaarClassifierCascade {};
 struct CvFeatureTree {};
 struct CvLSH {};
 // struct CvLSHOperations {}; // if cv.hpp is not included
@@ -43,11 +42,10 @@ namespace flann {
     class Index {};
 }
 
-#include "template_instantiations.hpp"
-
 
 // sdopencv stuff
 #include "sdopencv.hpp"
 
+#include "template_instantiations.hpp"
 
 #endif
